scopeKey property

Object? scopeKey
final

Serializes this scope with the others that share the key.

A scope with a key starts only once the previous holder has finished disposing of itself. Needs an AsyncScopeCoordinator above it.

Implementation

final Object? scopeKey;