Represents the ready state of a LiteScope when initialization is complete.
- Inheritance
-
- Object
- LiteScopeInitState
- LiteScopeReady
Constructors
- LiteScopeReady()
- Creates a LiteScopeReady state.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited