buildOnError abstract method
Builds a widget to display if an error occurs during initialization.
Implementation
Widget buildOnError(
BuildContext context,
Object error,
StackTrace stackTrace,
Object? progress,
);
Builds a widget to display if an error occurs during initialization.
Widget buildOnError(
BuildContext context,
Object error,
StackTrace stackTrace,
Object? progress,
);