ScopeCore<W extends ScopeCore<W, E, D, S>, E extends ScopeElementBase<W, E, D, S>, D extends ScopeDependencies, S extends ScopeCoreState<W, E, D, S>> class abstract base Scope

A core abstract class for scopes, bridging dependency injection with state management.

Inheritance
Implementers

Constructors

ScopeCore({Key? key, Object? tag, Widget child = const _NullWidget()})
Creates the widget half of a scope.
const

Properties

child → Widget
The widget below this widget in the tree.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag → Object?
Names this particular scope in the log.
finalinherited

Methods

createElement() → InheritedElement
Inflates this configuration to a concrete instance.
inherited
createScopeElement() → E
Creates the scope element for this lite scope.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort({bool showHashCode = false}) → String
A short, textual description of this widget.
inherited
updateShouldNotify(covariant ScopeWidgetCore<W, E> oldWidget) → bool
Whether the framework should notify widgets that inherit from this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

maybeOf<W extends ScopeCore<W, E, D, S>, E extends ScopeElementBase<W, E, D, S>, D extends ScopeDependencies, S extends ScopeCoreState<W, E, D, S>>(BuildContext context) → S?
Tries to find and return the state S of the scope W from the given context.
override
of<W extends ScopeCore<W, E, D, S>, E extends ScopeElementBase<W, E, D, S>, D extends ScopeDependencies, S extends ScopeCoreState<W, E, D, S>>(BuildContext context) → S
Finds and returns the state S of the scope W from the given context.
override
paramsOf<W extends ScopeCore<W, E, D, S>, E extends ScopeElementBase<W, E, D, S>, D extends ScopeDependencies, S extends ScopeCoreState<W, E, D, S>>(BuildContext context, {required bool listen}) → W
Looks up and returns the parameters of the scope W.
override
select<W extends ScopeCore<W, E, D, S>, E extends ScopeElementBase<W, E, D, S>, D extends ScopeDependencies, S extends ScopeCoreState<W, E, D, S>, V extends Object?>(BuildContext context, V selector(S scope)) → V
Selects and returns a specific value from the state S of the scope W using the selector and becomes dependent on it.
override
selectParam<W extends ScopeCore<W, E, D, S>, E extends ScopeElementBase<W, E, D, S>, D extends ScopeDependencies, S extends ScopeCoreState<W, E, D, S>, V extends Object?>(BuildContext context, V selector(W widget)) → V
Selects and returns a specific parameter of the scope W using the selector and becomes dependent on it.
override