ScopeDependencyFailedStates class sealed Scope

Inheritance
Implementers

Properties

count int
no setterinherited
description String
no setterinherited
error Object
no setterinherited
hasErrors bool
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace
no setterinherited

Methods

addError(Object error, StackTrace stackTrace) → _ScopeDependencyWithErrors
inherited
errors() List<AsyncError>
Возвращает копию списка ошибок.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString({bool? showCount, bool showErrors = true}) String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited