ScopeDependencyHandle class interface Scope

Properties

dispose FutureOr<void> Function()?
Releases what this dependency acquired; awaited during the disposal.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the dependency being initialized.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unmount ↔ void Function()?
Lets go of whatever cannot wait for dispose.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited