ScopeModel<M extends Object> class
final
ScopeModel
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- ProxyWidget
- InheritedWidget
- ScopeInheritedWidget
- ScopeWidgetCore<
ScopeModel< M> , _ScopeModelElement<ScopeModel< >M> , M> - ScopeModelCore<
ScopeModel< M> , _ScopeModelElement<ScopeModel< , M>M> , M> - ScopeModelBase<
ScopeModel< M> , M> - ScopeModel
Constructors
- ScopeModel({Key? key, Object? tag, required M create(BuildContext context)?, required void dispose(M model)?, required Widget builder(BuildContext context)})
-
Creates a scope that owns the model
createreturns.const - ScopeModel.value({Key? key, Object? tag, required M value, required Widget builder(BuildContext context)})
-
Creates a scope over a model somebody else owns.
const
Properties
- builder → Widget Function(BuildContext context)
-
final
- child → Widget
-
The widget below this widget in the tree.
finalinherited
- create → M Function(BuildContext context)?
-
finalinherited
- dispose → void Function(M model)?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasValue → bool
-
finalinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → Object?
-
Names this particular scope in the log.
finalinherited
- value → M?
-
finalinherited
Methods
-
build(
BuildContext context) → Widget -
inherited
-
createElement(
) → InheritedElement -
Inflates this configuration to a concrete instance.
inherited
-
createScopeElement(
) → _ScopeModelElement< ScopeModel< M> , M> -
Creates the element of this scope.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
{bool showHashCode = false}) → String -
A short, textual description of this widget.
inherited
-
updateShouldNotify(
covariant InheritedWidget oldWidget) → bool -
Whether the framework should notify widgets that inherit from this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
maybeOf<
M extends Object> (BuildContext context, {required bool listen}) → M? -
The model of the nearest
ScopeModel<M>, ornullif there is none.override -
of<
M extends Object> (BuildContext context, {required bool listen}) → M -
The model of the nearest
ScopeModel<M>.override -
select<
M extends Object, V extends Object?> (BuildContext context, V selector(M model)) → V -
Subscribes to one value of the model and returns it.
override