ScopeNotifier<M extends Listenable> class final ScopeNotifier

Inheritance

Constructors

ScopeNotifier({Key? key, Object? tag, required M create(BuildContext context)?, required void dispose(M model)?, required Widget builder(BuildContext context)})
const
ScopeNotifier.value({Key? key, required M? value, required Widget builder(BuildContext context)})
const

Properties

builder Widget Function(BuildContext context)
final
child Widget
The widget below this widget in the tree.
finalinherited
create → M Function(BuildContext context)?
finalinherited
dispose → void Function(M model)?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hasValue bool
finalinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag Object?
finalinherited
value → M?
finalinherited

Methods

build(BuildContext context) Widget
inherited
createElement() InheritedElement
Inflates this configuration to a concrete instance.
inherited
createScopeElement() → _ScopeNotifierElement<ScopeNotifier<M>, M>
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort({bool showHashCode = false}) String
A short, textual description of this widget.
inherited
updateShouldNotify(covariant InheritedWidget oldWidget) bool
Whether the framework should notify widgets that inherit from this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

maybeOf<M extends Listenable>(BuildContext context, {required bool listen}) → M?
override
of<M extends Listenable>(BuildContext context, {required bool listen}) → M
override
select<M extends Listenable, V extends Object?>(BuildContext context, V selector(M model)) → V
override