ScopeNotifierAccess<W extends ScopeNotifierBase<W, M>, M extends Listenable> class final ScopeNotifier

The three accessors of one ScopeNotifierBase, with its type arguments named once.

final class CounterScope extends ScopeNotifierBase<CounterScope, Counter> {
  static const access = ScopeNotifierAccess<CounterScope, Counter>();
  …
}

Constructors

ScopeNotifierAccess()
Creates an accessor for the scope W.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

maybeOf(BuildContext context, {required bool listen}) ScopeModelContext<W, M>?
Tries to find and return the context of the scope.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
of(BuildContext context, {required bool listen}) ScopeModelContext<W, M>
Finds and returns the context of the scope, or throws.
select<V extends Object?>(BuildContext context, V selector(ScopeModelContext<W, M> context)) → V
Selects a value from the scope context and subscribes to it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited