ScopeNotifierBase<W extends ScopeNotifierBase<W, M> , M extends Listenable> class
abstract
base
ScopeNotifier
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- ProxyWidget
- InheritedWidget
- ScopeInheritedWidget
- ScopeWidgetCore<
W, _ScopeNotifierElement< W, M> > - ScopeModelCore<
W, _ScopeNotifierElement< W, M> , M> - ScopeNotifierCore<
W, _ScopeNotifierElement< W, M> , M> - ScopeNotifierBase
- Implementers
Constructors
- ScopeNotifierBase({Key? key, Object? tag, required M create(BuildContext context)?, required void dispose(M model)?, Widget child = const _NullWidget()})
-
const
- ScopeNotifierBase.value({Key? key, Object? tag, required M? value})
-
const
Properties
- child → Widget
-
The widget below this widget in the tree.
finalinherited
- create → M Function(BuildContext context)?
-
final
- dispose → void Function(M model)?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasValue → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → Object?
-
finalinherited
- value → M?
-
final
Methods
-
build(
BuildContext context) → Widget -
createElement(
) → InheritedElement -
Inflates this configuration to a concrete instance.
inherited
-
createScopeElement(
) → _ScopeNotifierElement< W, M> -
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
{bool showHashCode = false}) → String -
A short, textual description of this widget.
inherited
-
updateShouldNotify(
covariant InheritedWidget oldWidget) → bool -
Whether the framework should notify widgets that inherit from this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
maybeOf<
W extends ScopeNotifierBase< (W, M> , M extends Listenable>BuildContext context, {required bool listen}) → ScopeModelContext< W, M> ? -
override
-
of<
W extends ScopeNotifierBase< (W, M> , M extends Listenable>BuildContext context, {required bool listen}) → ScopeModelContext< W, M> -
override
-
select<
W extends ScopeNotifierBase< (W, M> , M extends Listenable, V extends Object?>BuildContext context, V selector(ScopeModelContext< W, M> context)) → V -
override