AsyncDataScopeAccess<W extends AsyncDataScopeBase<W, T> , T extends Object?> class
final
AsyncDataScope
The three accessors of one AsyncDataScopeBase, with its type arguments named once.
final class DbScope extends AsyncDataScopeBase<DbScope, Database> {
static const access = AsyncDataScopeAccess<DbScope, Database>();
…
}
Constructors
- AsyncDataScopeAccess()
-
Creates an accessor for the scope
W.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
maybeOf(
BuildContext context, {required bool listen}) → AsyncDataScopeContext< W, T> ? - Tries to find and return the context of the scope.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
of(
BuildContext context, {required bool listen}) → AsyncDataScopeContext< W, T> - Finds and returns the context of the scope, or throws.
-
select<
V extends Object?> (BuildContext context, V selector(AsyncDataScopeContext< W, T> context)) → V - Selects a value from the scope context and subscribes to it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited