AsyncScopeAccess<W extends AsyncScopeBase<W> > class
final
AsyncScope
The three accessors of one AsyncScopeBase, with its type argument named once.
final class ConnectionScope extends AsyncScopeBase<ConnectionScope> {
static const access = AsyncScopeAccess<ConnectionScope>();
…
}
Constructors
- AsyncScopeAccess()
-
Creates an accessor for the scope
W.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
maybeOf(
BuildContext context, {required bool listen}) → AsyncScopeContext< W> ? - Tries to find and return the context of the scope.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
of(
BuildContext context, {required bool listen}) → AsyncScopeContext< W> - Finds and returns the context of the scope, or throws.
-
select<
V extends Object?> (BuildContext context, V selector(AsyncScopeContext< W> context)) → V - Selects a value from the scope context and subscribes to it.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited