Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
equals(
Object? a, Object? b) → bool -
a == b, as a function that can be passed around. -
identical(
Object? a, Object? b) → bool -
Whether
aandbare the same object. -
notEquals(
Object? a, Object? b) → bool -
a != b, as a function that can be passed around. -
notIdentical(
Object? a, Object? b) → bool -
Whether
aandbare different objects.