- Implemented types
- Available extensions
Constructors
- ListenableView(T listenable)
-
Wraps
listenableso that only listening is reachable through it.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object notifies its listeners.
override
-
listen(
void callback()) → ListenableSubscription -
Available on Listenable, provided by the ListenableListenExtension extension
Listen to the Listenable. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies.
override
-
select<
T extends Object?> (T selector(L listenable), void listener(L listenable, T value), {bool compare(T previous, T current)?}) → ListenableSelectSubscription< T> -
Available on L, provided by the ListenableSelectExtension extension
Listen to a specific value of the Listenable. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited