Constructors
-
Progress(int number, int total)
-
Creates a progress value of
number steps out of total.
const
Properties
-
hashCode
→ int
-
The hash code for this object.
no setteroverride
-
number
→ int
-
The steps taken so far.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
total
→ int
-
The steps there are in total.
final
-
value
→ double
-
The progress as a fraction between 0 and 1, for a progress indicator.
no setter
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
override