Constructors
- ScopeDependencyInfo({required int level, required String path, required ScopeDependency dependency})
-
Creates an entry of a tree walk.
const
Properties
- dependency → ScopeDependency
-
The dependency itself.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- level → int
-
How deep in the tree the dependency sits.
final
- path → String
-
The path of the enclosing groups, ending with
/when not empty.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
indent(
[String indent = ' ']) → String - The indentation matching level, for printing a tree.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited