Constructors
-
ScopeLog(CustomLevelLogger<CustomLogger<dynamic, dynamic, Function, CustomLog>, CustomLevelLogger<dynamic, dynamic, Function, CustomLog>, Function, CustomLog> levelLogger, {Object? error, StackTrace? stackTrace, required LazyString path, required Object? message})
-
Properties
-
error
→ Object?
-
An optional error or exception object associated with this log event.
finalinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
level
→ int
-
The numerical severity value of this log event.
finalinherited
-
levelName
→ String
-
The display name for the severity level (e.g., "INFO", "ERROR").
finalinherited
-
message
→ String?
-
no setter
-
path
→ String
-
no setter
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
shortLevelName
→ String
-
A shortened representation of the level's display name.
finalinherited
-
stackTrace
→ StackTrace?
-
An optional stack trace associated with the error or log event.
finalinherited
-
timestamp
→ DateTime
-
final
-
zone
→ Zone
-
The asynchronous Zone in which this log event was produced.
finalinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited