ScopeLogger class final
Constructors
- ScopeLogger(Object name)
Properties
- d → ScopeLogFn
-
no setter
- e → ScopeLogFn
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- i → ScopeLogFn
-
no setter
- level ↔ int
-
The overall log level threshold of this logger.
getter/setter pairinherited
- levelLinked → bool
-
Returns
trueif this logger's level is synchronized with its parent.no setterinherited - path → String
-
no setter
- pathSeparator ↔ String
-
getter/setter pair
-
publisher
← CustomLogPublisher<
ScopeLog> -
Assigns a common
CustomLogPublisherto all registered log levels.no getterinherited - publisherLinked → bool
-
Returns
trueif this logger's publisher is synchronized with its parent.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subLoggersCount → int
-
Returns the number of directly attached subloggers.
no setterinherited
- v → ScopeLogFn
-
no setter
Methods
-
isLoggable(
int level) → bool -
Returns
trueif the specifiedlevelmeets the logging threshold.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerLevel(
ScopeLevelLogger levelLogger) → void -
Registers a specific
levelLoggerdynamically.inherited -
registerLevels(
) → void - Registers all the log levels supported by this logger.
-
registerSublogger(
ScopeLogger sublogger) → void -
Subscribes a
subloggerto level and publisher updates dynamically.inherited -
toString(
) → String -
A string representation of this object.
inherited
-
withAddedName(
Object name) → ScopeLogger
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
int level) → ScopeLevelLogger -
Retrieves the
LevelLoggerassociated with the given numericallevel.inherited
Static Methods
-
defaultFormat(
ScopeLog entry) → String