ScopeStateWithErrorModel<S extends Object> class
abstract
interface
ScopeNotifier
- Implemented types
- Implementers
- Available extensions
Properties
- error → Object
-
The error, when there is one.
no setter
- hasError → bool
-
Whether the state carries an error.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace
-
The stack trace of error.
no setter
- state → S
-
The current state.
no setteroverride
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object notifies its listeners.
inherited
-
listen(
void callback()) → ListenableSubscription -
Available on Listenable, provided by the ListenableListenExtension extension
Listen to the Listenable. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies.
inherited
-
select<
T extends Object?> (T selector(L listenable), void listener(L listenable, T value), {bool compare(T previous, T current)?}) → ListenableSelectSubscription< T> -
Available on L, provided by the ListenableSelectExtension extension
Listen to a specific value of the Listenable. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited