ScopeWaitingBuilder typedef Scope
ScopeWaitingBuilder =
Widget? Function(BuildContext context)
A builder function used to display a waiting widget while the Scope is waiting for a Scope.scopeKey and Scope.initDependencies to send their first state.
Implementation
typedef ScopeWaitingBuilder = Widget? Function(BuildContext context);